/* EGG - The GIMP Toolkit
 * eggprintsettings.h: Print Settings
 * Copyright (C) 2005, Red Hat, Inc.
 *
 * This library is free software; you can redistribute it and/or
 * modify it under the terms of the GNU Lesser General Public
 * License as published by the Free Software Foundation; either
 * version 2 of the License, or (at your option) any later version.
 *
 * This library is distributed in the hope that it will be useful,
 * but WITHOUT ANY WARRANTY; without even the implied warranty of
 * MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the GNU
 * Lesser General Public License for more details.
 *
 * You should have received a copy of the GNU Lesser General Public
 * License along with this library; if not, write to the
 * Free Software Foundation, Inc., 59 Temple Place - Suite 330,
 * Boston, MA 02111-1307, USA.
 */

#include <math.h>
#include <pango/pangocairo.h>
#include <gtk/gtk.h>
#include "eggprint.h"
#include "testprintfileoperation.h"

static gboolean
draw_page (EggPrintOperation *operation,
	   EggPrintContext *context,
	   int page_nr)
{
  cairo_t *cr;
  PangoLayout *layout;
  PangoFontDescription *desc;
  
  if (page_nr != 0)
    return FALSE;

  cr = egg_print_context_get_cairo (context);

  /* Draw a red rectangle, as wide as the paper inside the margins */
  cairo_set_source_rgb (cr, 1.0, 0, 0);
  cairo_rectangle (cr, 0, 0, egg_print_context_get_width (context), 50);
  
  cairo_fill (cr);

  /* Draw some lines */
  cairo_move_to (cr, 20, 10);
  cairo_line_to (cr, 40, 20);
  cairo_arc (cr, 60, 60, 20, 0, M_PI);
  cairo_line_to (cr, 80, 20);
  
  cairo_set_source_rgb (cr, 0, 0, 0);
  cairo_set_line_width (cr, 5);
  cairo_set_line_cap (cr, CAIRO_LINE_CAP_ROUND);
  cairo_set_line_join (cr, CAIRO_LINE_JOIN_ROUND);
  
  cairo_stroke (cr);

  /* Draw some text */
  
  layout = egg_print_context_create_layout (context);
  pango_layout_set_text (layout, "Hello World! Printing is easy", -1);
  desc = pango_font_description_from_string ("sans 28");
  pango_layout_set_font_description (layout, desc);
  pango_font_description_free (desc);

  cairo_move_to (cr, 30, 20);
  pango_cairo_layout_path (cr, layout);

  /* Font Outline */
  cairo_set_source_rgb (cr, 0.93, 1.0, 0.47);
  cairo_set_line_width (cr, 0.5);
  cairo_stroke_preserve (cr);

  /* Font Fill */
  cairo_set_source_rgb (cr, 0, 0.0, 1.0);
  cairo_fill (cr);
  
  g_object_unref (layout);

  return TRUE;
}

int
main (int argc, char **argv)
{
  EggPrintOperation *print;
  TestPrintFileOperation *print_file;

  gtk_init (&argc, &argv);

  print = egg_print_operation_new ();
  egg_print_operation_set_unit (print, EGG_UNIT_MM);
  egg_print_operation_set_pdf_target (print, "test.pdf");

  g_signal_connect (print, "draw_page", G_CALLBACK (draw_page), NULL);
  
  egg_print_operation_run (print);

  print_file = test_print_file_operation_new ("testprint.c");
  test_print_file_operation_set_lines_per_page (print_file, 72);
  egg_print_operation_set_pdf_target (EGG_PRINT_OPERATION (print_file), "test2.pdf");
  egg_print_operation_run (EGG_PRINT_OPERATION (print_file));
  
  return 0;
}
